%
% The function uses MATLAB's built in option valuation and sensitivity toolbox to calculate
% various statistics relating to the European option. The function calculates the following:
%	1) Price - option price of both the European put and call option
%	2) Delta - the sensitivity in option value to changes in the underlying asset price
%	3) Lambda - the percent change in option value to a one percent change in the underlying asset price 
%	4) Rho - the sensitivity in option value to changes in the interest rate
%	5) Theta - the sensitivity in option value to changes in time to maturity
%	6) Gamma - the sensitivity in option value to changes in the options delta (or second derivative of asset price)
%	7) Vega - the sensitivity in option value to changes in the volatility of the underlying asset
% The function then returns two vectors (one for the call option, one for the put option) that contain the various metrics
%
function [Call, Put] = blackScholesInfo(Price, Strike, Rate, Time, Volatility)
	[CallPrice, PutPrice] = blkprice(Price, Strike, Rate, Time, Volatility);
	[CallDelta, PutDelta] = blsdelta(Price, Strike, Rate, Time, Volatility);
	[CallLambda, PutLambda] = blslambda(Price, Strike, Rate, Time, Volatility);
	[CallRho, PutRho] = blsrho(Price, Strike, Rate, Time, Volatility);
	[CallTheta, PutTheta] = blstheta(Price, Strike, Rate, Time, Volatility); 
	gamma = blsgamma(Price, Strike, Rate, Time, Volatility);
	vega = blsvega(Price, Strike, Rate, Time, Volatility);
	Call =[CallPrice, CallLambda, CallDelta, CallRho, CallTheta, gamma, vega];
	Put = [PutPrice, PutLambda, PutDelta, PutRho, PutTheta, gamma, vega];
	
